import { Keypair, PublicKey } from '@solana/web3.js';
import * as ed25519 from '@noble/ed25519';

class Web3JsEddsa {
  generateKeypair() {
    return Keypair.generate();
  }
  createKeypairFromSecretKey(secretKey) {
    return Keypair.fromSecretKey(secretKey);
  }
  createKeypairFromSeed(seed) {
    return Keypair.fromSeed(seed);
  }
  createPublicKey(input) {
    return new PublicKey(input);
  }
  createDefaultPublicKey() {
    return PublicKey.default;
  }
  isOnCurve(input) {
    return PublicKey.isOnCurve(input);
  }
  findPda(programId, seeds) {
    const [key, bump] = PublicKey.findProgramAddressSync(seeds, new PublicKey(programId));
    return {
      ...key,
      bump
    };
  }
  sign(message, keypair) {
    return ed25519.sync.sign(message, keypair.secretKey.slice(0, 32));
  }
  verify(message, signature, publicKey) {
    return ed25519.sync.verify(signature, message, publicKey.toBytes());
  }
}

export { Web3JsEddsa };
//# sourceMappingURL=Web3JsEddsa.mjs.map
